from setuptools import setup

setup (name="calculatorbywardasalwa",
version="0.1",
description="this is a package",
long_description="this is a very very long description",
author = "Warda and Salwa",
packages = [""],
install_packages = []
)